From 43b9359fabe5c153a02081ae56047b9e121dce02 Mon Sep 17 00:00:00 2001
From: Tom Rondeau <trondeau@vt.edu>
Date: Sun, 27 Mar 2011 12:59:52 -0400
Subject: gr-qtgui: moving Python files to new structure; get rid of src
 directory.

---
 gr-qtgui/python/qa_qtgui.py | 46 +++++++++++++++++++++++++++++++++++++++++++++
 1 file changed, 46 insertions(+)
 create mode 100755 gr-qtgui/python/qa_qtgui.py

(limited to 'gr-qtgui/python/qa_qtgui.py')

diff --git a/gr-qtgui/python/qa_qtgui.py b/gr-qtgui/python/qa_qtgui.py
new file mode 100755
index 0000000000..fbf0de46e3
--- /dev/null
+++ b/gr-qtgui/python/qa_qtgui.py
@@ -0,0 +1,46 @@
+#!/usr/bin/env python
+#
+# Copyright 2011 Free Software Foundation, Inc.
+# 
+# This file is part of GNU Radio
+# 
+# GNU Radio is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3, or (at your option)
+# any later version.
+# 
+# GNU Radio is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with GNU Radio; see the file COPYING.  If not, write to
+# the Free Software Foundation, Inc., 51 Franklin Street,
+# Boston, MA 02110-1301, USA.
+# 
+
+from gnuradio import gr, gr_unittest
+import qtgui
+from PyQt4 import QtGui, QtCore
+import sys, sip
+
+class test_qtgui(gr_unittest.TestCase):
+
+    def setUp (self):
+        self.tb = gr.top_block ()
+
+    def tearDown (self):
+        self.tb = None
+    
+    def test01 (self):
+        pass
+        # Test to make sure we can instantiate these
+        #self.qapp = QtGui.QApplication(sys.argv)
+        #self.qtsnk = qtgui.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
+        #                          0, 1, "Test",
+        #                          True, True, False, True, True)
+        
+        
+if __name__ == '__main__':
+    gr_unittest.run(test_qtgui, "test_qtgui.xml")
-- 
cgit v1.2.3


From 9ebfa393e94a5614fccac987a7044bc66814af78 Mon Sep 17 00:00:00 2001
From: Tom Rondeau <trondeau@vt.edu>
Date: Sun, 27 Mar 2011 14:15:41 -0400
Subject: gr-qtgui: small correction in Python QA code with new structure.

---
 gr-qtgui/python/qa_qtgui.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

(limited to 'gr-qtgui/python/qa_qtgui.py')

diff --git a/gr-qtgui/python/qa_qtgui.py b/gr-qtgui/python/qa_qtgui.py
index fbf0de46e3..7d3cf80985 100755
--- a/gr-qtgui/python/qa_qtgui.py
+++ b/gr-qtgui/python/qa_qtgui.py
@@ -21,7 +21,7 @@
 # 
 
 from gnuradio import gr, gr_unittest
-import qtgui
+import qtgui_swig
 from PyQt4 import QtGui, QtCore
 import sys, sip
 
@@ -37,9 +37,9 @@ class test_qtgui(gr_unittest.TestCase):
         pass
         # Test to make sure we can instantiate these
         #self.qapp = QtGui.QApplication(sys.argv)
-        #self.qtsnk = qtgui.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
-        #                          0, 1, "Test",
-        #                          True, True, False, True, True)
+        #self.qtsnk = qtgui_swig.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
+        #                               0, 1, "Test",
+        #                               True, True, False, True, True)
         
         
 if __name__ == '__main__':
-- 
cgit v1.2.3


From 8f53f5a782a6500d191ba557b37e7e3785cf6e02 Mon Sep 17 00:00:00 2001
From: Tom Rondeau <trondeau@vt.edu>
Date: Wed, 6 Apr 2011 00:22:29 -0400
Subject: gr-qtgui: removing references to 3D waterfall plot and changning
 QtGui API to remove bool that turns it on/off.

---
 gr-qtgui/apps/pyqt_example_c.py     |  2 +-
 gr-qtgui/apps/pyqt_example_f.py     |  2 +-
 gr-qtgui/apps/qt_digital.py         |  4 ++--
 gr-qtgui/apps/usrp2_display.py      |  2 +-
 gr-qtgui/apps/usrp_display.py       |  2 +-
 gr-qtgui/grc/qtgui_sink_x.xml       | 10 ----------
 gr-qtgui/lib/.gitignore             |  1 -
 gr-qtgui/lib/qtgui_sink_c.cc        | 13 +++----------
 gr-qtgui/lib/qtgui_sink_c.h         | 10 +++-------
 gr-qtgui/lib/qtgui_sink_f.cc        | 13 +++----------
 gr-qtgui/lib/qtgui_sink_f.h         |  9 +++------
 gr-qtgui/lib/spectrumdisplayform.cc |  2 --
 gr-qtgui/lib/spectrumdisplayform.h  |  2 --
 gr-qtgui/python/qa_qtgui.py         | 10 +++++-----
 gr-qtgui/swig/qtgui_swig.i          | 18 ++++++------------
 15 files changed, 29 insertions(+), 71 deletions(-)

(limited to 'gr-qtgui/python/qa_qtgui.py')

diff --git a/gr-qtgui/apps/pyqt_example_c.py b/gr-qtgui/apps/pyqt_example_c.py
index e1fb8a6beb..90eec3694f 100755
--- a/gr-qtgui/apps/pyqt_example_c.py
+++ b/gr-qtgui/apps/pyqt_example_c.py
@@ -121,7 +121,7 @@ class my_top_block(gr.top_block):
         self.snk1 = qtgui.sink_c(fftsize, gr.firdes.WIN_BLACKMAN_hARRIS,
                                  0, Rs,
                                  "Complex Signal Example",
-                                 True, True, False, True, False)
+                                 True, True, True, False)
 
         self.connect(src1, (src,0))
         self.connect(src2, (src,1))
diff --git a/gr-qtgui/apps/pyqt_example_f.py b/gr-qtgui/apps/pyqt_example_f.py
index 55d9873296..29905b8d97 100755
--- a/gr-qtgui/apps/pyqt_example_f.py
+++ b/gr-qtgui/apps/pyqt_example_f.py
@@ -120,7 +120,7 @@ class my_top_block(gr.top_block):
         self.snk1 = qtgui.sink_f(fftsize, gr.firdes.WIN_BLACKMAN_hARRIS,
                                  0, Rs,
                                  "Float Signal Example",
-                                 True, True, False, True, False)
+                                 True, True, True, False)
 
         self.connect(src1, (src,0))
         self.connect(src2, (src,1))
diff --git a/gr-qtgui/apps/qt_digital.py b/gr-qtgui/apps/qt_digital.py
index 7b9e9b7734..c6920a05d0 100755
--- a/gr-qtgui/apps/qt_digital.py
+++ b/gr-qtgui/apps/qt_digital.py
@@ -185,11 +185,11 @@ class my_top_block(gr.top_block):
         self.thr = gr.throttle(gr.sizeof_char, self._sample_rate)
         self.snk_tx = qtgui.sink_c(fftsize, gr.firdes.WIN_BLACKMAN_hARRIS, 
                                    0, self._sample_rate*self.sps,
-                                   "Tx", True, True, False, True, True)
+                                   "Tx", True, True, True, True)
 
         self.snk_rx = qtgui.sink_c(fftsize, gr.firdes.WIN_BLACKMAN_hARRIS,
                                    0, self._sample_rate,
-                                   "Rx", True, True, False, True, True)
+                                   "Rx", True, True, True, True)
 
         self.connect(self.src, self.thr, self.mod, self.channel, self.snk_tx)
         self.connect(self.channel, self.rx_rrc, self.receiver, self.snk_rx)
diff --git a/gr-qtgui/apps/usrp2_display.py b/gr-qtgui/apps/usrp2_display.py
index 75d374c2bd..ab1a6f742c 100755
--- a/gr-qtgui/apps/usrp2_display.py
+++ b/gr-qtgui/apps/usrp2_display.py
@@ -210,7 +210,7 @@ class my_top_block(gr.top_block):
         self.snk = qtgui.sink_c(options.fft_size, gr.firdes.WIN_BLACKMAN_hARRIS,
                                 self._freq, self._bandwidth,
                                 "USRP2 Display",
-                                True, True, False, True, False)
+                                True, True, True, False)
 
         # Set up internal amplifier
         self.amp = gr.multiply_const_cc(0.0)
diff --git a/gr-qtgui/apps/usrp_display.py b/gr-qtgui/apps/usrp_display.py
index 432e74d9a0..131bc4a7e1 100755
--- a/gr-qtgui/apps/usrp_display.py
+++ b/gr-qtgui/apps/usrp_display.py
@@ -229,7 +229,7 @@ class my_top_block(gr.top_block):
         self.snk = qtgui.sink_c(self._fftsize, gr.firdes.WIN_BLACKMAN_hARRIS,
                                 self._freq, self._bandwidth,
                                 "USRP Display",
-                                True, True, False, True, False)
+                                True, True, True, False)
 
         # Set up internal amplifier
         self.amp = gr.multiply_const_cc(0.0)
diff --git a/gr-qtgui/grc/qtgui_sink_x.xml b/gr-qtgui/grc/qtgui_sink_x.xml
index 7a5f5ec135..8c470a1a5f 100644
--- a/gr-qtgui/grc/qtgui_sink_x.xml
+++ b/gr-qtgui/grc/qtgui_sink_x.xml
@@ -21,7 +21,6 @@ qtgui.$(type.fcn)(
 	$name, \#name
 	$plotfreq, \#plotfreq
 	$plotwaterfall, \#plotwaterfall
-	$plotwaterfall3d, \#plotwaterfall3d
 	$plottime, \#plottime
 	$plotconst, \#plotconst
 )
@@ -89,15 +88,6 @@ $(gui_hint()($win))</make>
 		<option><name>On</name><key>True</key></option>
 		<option><name>Off</name><key>False</key></option>
 	</param>
-	<param>
-		<name>Plot Waterfall 3D</name>
-		<key>plotwaterfall3d</key>
-		<value>True</value>
-		<type>bool</type>
-		<hide>part</hide>
-		<option><name>On</name><key>True</key></option>
-		<option><name>Off</name><key>False</key></option>
-	</param>
 	<param>
 		<name>Plot Time</name>
 		<key>plottime</key>
diff --git a/gr-qtgui/lib/.gitignore b/gr-qtgui/lib/.gitignore
index 61b9ca8c19..fc4f8cdfe7 100644
--- a/gr-qtgui/lib/.gitignore
+++ b/gr-qtgui/lib/.gitignore
@@ -5,7 +5,6 @@
 /qtgui.cc
 /qtgui.py
 /WaterfallDisplayPlot.moc.cc
-/Waterfall3DDisplayPlot.moc.cc
 /TimeDomainDisplayPlot.moc.cc
 /spectrumdisplayform.moc.cc
 /spectrumdisplayform.ui.h
diff --git a/gr-qtgui/lib/qtgui_sink_c.cc b/gr-qtgui/lib/qtgui_sink_c.cc
index bdd941fe1b..4cbd47c550 100644
--- a/gr-qtgui/lib/qtgui_sink_c.cc
+++ b/gr-qtgui/lib/qtgui_sink_c.cc
@@ -35,16 +35,14 @@ qtgui_make_sink_c (int fftsize, int wintype,
 		   double fc, double bw,
 		   const std::string &name,
 		   bool plotfreq, bool plotwaterfall,
-		   bool plotwaterfall3d, bool plottime,
-		   bool plotconst,
+		   bool plottime, bool plotconst,
 		   bool use_openGL,
 		   QWidget *parent)
 {
   return gnuradio::get_initial_sptr(new qtgui_sink_c (fftsize, wintype,
 					      fc, bw, name,
 					      plotfreq, plotwaterfall,
-					      plotwaterfall3d, plottime,
-					      plotconst,
+					      plottime, plotconst,
 					      use_openGL,
 					      parent));
 }
@@ -53,8 +51,7 @@ qtgui_sink_c::qtgui_sink_c (int fftsize, int wintype,
 			    double fc, double bw,
 			    const std::string &name,
 			    bool plotfreq, bool plotwaterfall,
-			    bool plotwaterfall3d, bool plottime,
-			    bool plotconst,
+			    bool plottime, bool plotconst,
 			    bool use_openGL,
 			    QWidget *parent)
   : gr_block ("sink_c",
@@ -67,10 +64,6 @@ qtgui_sink_c::qtgui_sink_c (int fftsize, int wintype,
     d_plottime(plottime), d_plotconst(plotconst),
     d_parent(parent)
 {
-  if(plotwaterfall3d == true) {
-    fprintf(stderr, "Warning: plotting Waterfall3D has been removed; enabling plotwaterfall3d has no effect.\n");
-  }
-
   d_main_gui = NULL;
 
   // Perform fftshift operation;
diff --git a/gr-qtgui/lib/qtgui_sink_c.h b/gr-qtgui/lib/qtgui_sink_c.h
index 59b5acfe52..22ca07f773 100644
--- a/gr-qtgui/lib/qtgui_sink_c.h
+++ b/gr-qtgui/lib/qtgui_sink_c.h
@@ -28,7 +28,6 @@
 #include <gr_firdes.h>
 #include <gri_fft.h>
 #include <qapplication.h>
-//#include <qtgui.h>
 #include "SpectrumGUIClass.h"
 
 class qtgui_sink_c;
@@ -38,8 +37,7 @@ qtgui_sink_c_sptr qtgui_make_sink_c (int fftsize, int wintype,
 				     double fc=0, double bandwidth=1.0,
 				     const std::string &name="Spectrum Display",
 				     bool plotfreq=true, bool plotwaterfall=true,
-				     bool plotwaterfall3d=true, bool plottime=true,
-				     bool plotconst=true,
+				     bool plottime=true, bool plotconst=true,
 				     bool use_openGL=true,
 				     QWidget *parent=NULL);
 
@@ -50,16 +48,14 @@ private:
 					      double fc, double bw,
 					      const std::string &name,
 					      bool plotfreq, bool plotwaterfall,
-					      bool plotwaterfall3d, bool plottime,
-					      bool plotconst,
+					      bool plottime, bool plotconst,
 					      bool use_openGL,
 					      QWidget *parent);
   qtgui_sink_c (int fftsize, int wintype,
 		double fc, double bw, 
 		const std::string &name,
 		bool plotfreq, bool plotwaterfall,
-		bool plotwaterfall3d, bool plottime,
-		bool plotconst,
+		bool plottime, bool plotconst,
 		bool use_openGL,
 		QWidget *parent);
 
diff --git a/gr-qtgui/lib/qtgui_sink_f.cc b/gr-qtgui/lib/qtgui_sink_f.cc
index e27ff3ac1b..90d4d7a708 100644
--- a/gr-qtgui/lib/qtgui_sink_f.cc
+++ b/gr-qtgui/lib/qtgui_sink_f.cc
@@ -35,16 +35,14 @@ qtgui_make_sink_f (int fftsize, int wintype,
 		   double fc, double bw,
 		   const std::string &name,
 		   bool plotfreq, bool plotwaterfall,
-		   bool plotwaterfall3d, bool plottime,
-		   bool plotconst,
+		   bool plottime, bool plotconst,
 		   bool use_openGL,
 		   QWidget *parent)
 {
   return gnuradio::get_initial_sptr(new qtgui_sink_f (fftsize, wintype,
 					      fc, bw, name,
 					      plotfreq, plotwaterfall,
-					      plotwaterfall3d, plottime,
-					      plotconst,
+					      plottime, plotconst,
 					      use_openGL,
 					      parent));
 }
@@ -53,8 +51,7 @@ qtgui_sink_f::qtgui_sink_f (int fftsize, int wintype,
 			    double fc, double bw,
 			    const std::string &name,
 			    bool plotfreq, bool plotwaterfall,
-			    bool plotwaterfall3d, bool plottime,
-			    bool plotconst,
+			    bool plottime, bool plotconst,
 			    bool use_openGL,
 			    QWidget *parent)
   : gr_block ("sink_f",
@@ -67,10 +64,6 @@ qtgui_sink_f::qtgui_sink_f (int fftsize, int wintype,
     d_plottime(plottime), d_plotconst(plotconst),
     d_parent(parent)
 {
-  if(plotwaterfall3d == true) {
-    fprintf(stderr, "Warning: plotting Waterfall3D has been removed; enabling plotwaterfall3d has no effect.\n");
-  }
-
   d_main_gui = NULL;
 
   // Perform fftshift operation;
diff --git a/gr-qtgui/lib/qtgui_sink_f.h b/gr-qtgui/lib/qtgui_sink_f.h
index a798a41bb1..8f27d120ac 100644
--- a/gr-qtgui/lib/qtgui_sink_f.h
+++ b/gr-qtgui/lib/qtgui_sink_f.h
@@ -38,8 +38,7 @@ qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
 				     double fc=0, double bw=1.0,
 				     const std::string &name="Spectrum Display",
 				     bool plotfreq=true, bool plotwaterfall=true,
-				     bool plotwaterfall3d=true, bool plottime=true,
-				     bool plotconst=true,
+				     bool plottime=true, bool plotconst=true,
 				     bool use_openGL=true,
 				     QWidget *parent=NULL);
 
@@ -50,16 +49,14 @@ private:
 					      double fc, double bw,
 					      const std::string &name,
 					      bool plotfreq, bool plotwaterfall,
-					      bool plotwaterfall3d, bool plottime,
-					      bool plotconst,
+					      bool plottime, bool plotconst,
 					      bool use_openGL,
 					      QWidget *parent);
   qtgui_sink_f (int fftsize, int wintype,
 		double fc, double bw,
 		const std::string &name,
 		bool plotfreq, bool plotwaterfall,
-		bool plotwaterfall3d, bool plottime,
-		bool plotconst,
+		bool plottime, bool plotconst,
 		bool use_openGL,
 		QWidget *parent);
 
diff --git a/gr-qtgui/lib/spectrumdisplayform.cc b/gr-qtgui/lib/spectrumdisplayform.cc
index d4fc037810..101bbc52b5 100644
--- a/gr-qtgui/lib/spectrumdisplayform.cc
+++ b/gr-qtgui/lib/spectrumdisplayform.cc
@@ -3,8 +3,6 @@
 #include <QMessageBox>
 #include <spectrumdisplayform.h>
 
-int SpectrumDisplayForm::_openGLWaterfall3DFlag = -1;
-
 SpectrumDisplayForm::SpectrumDisplayForm(bool useOpenGL, QWidget* parent)
   : QWidget(parent)
 {
diff --git a/gr-qtgui/lib/spectrumdisplayform.h b/gr-qtgui/lib/spectrumdisplayform.h
index fbd08349bf..e760ccc130 100644
--- a/gr-qtgui/lib/spectrumdisplayform.h
+++ b/gr-qtgui/lib/spectrumdisplayform.h
@@ -95,7 +95,6 @@ private:
   double _noiseFloorAmplitude;
   double _peakFrequency;
   double _peakAmplitude;
-  static int _openGLWaterfall3DFlag;
   double _stopFrequency;
   
   //SpectrumUpdateEvent _lastSpectrumEvent;
@@ -103,7 +102,6 @@ private:
   // whether or not to use a particular display
   int d_plot_fft;
   int d_plot_waterfall;
-  int d_plot_waterfall3d;
   int d_plot_time;
   int d_plot_constellation;
 
diff --git a/gr-qtgui/python/qa_qtgui.py b/gr-qtgui/python/qa_qtgui.py
index 7d3cf80985..dd6529ce0d 100755
--- a/gr-qtgui/python/qa_qtgui.py
+++ b/gr-qtgui/python/qa_qtgui.py
@@ -34,12 +34,12 @@ class test_qtgui(gr_unittest.TestCase):
         self.tb = None
     
     def test01 (self):
-        pass
+        #pass
         # Test to make sure we can instantiate these
-        #self.qapp = QtGui.QApplication(sys.argv)
-        #self.qtsnk = qtgui_swig.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
-        #                               0, 1, "Test",
-        #                               True, True, False, True, True)
+        self.qapp = QtGui.QApplication(sys.argv)
+        self.qtsnk = qtgui_swig.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
+                                       0, 1, "Test",
+                                       True, True, True, True)
         
         
 if __name__ == '__main__':
diff --git a/gr-qtgui/swig/qtgui_swig.i b/gr-qtgui/swig/qtgui_swig.i
index ba97b4e9aa..8069ed6c2f 100644
--- a/gr-qtgui/swig/qtgui_swig.i
+++ b/gr-qtgui/swig/qtgui_swig.i
@@ -33,8 +33,7 @@ GR_SWIG_BLOCK_MAGIC(qtgui,sink_c)
 				       double fc=0, double bw=1.0,
 				       const std::string &name="Display",
 				       bool plotfreq=true, bool plotwaterfall=true,
-				       bool plotwaterfall3d=true, bool plottime=true,
-				       bool plotconst=true,
+				       bool plottime=true, bool plotconst=true,
 				       bool use_openGL=true,
 				       QWidget *parent=NULL);
 
@@ -45,16 +44,14 @@ private:
 					      double fc, double bw,
 					      const std::string &name,
 					      bool plotfreq, bool plotwaterfall,
-					      bool plotwaterfall3d, bool plottime,
-					      bool plotconst,
+					      bool plottime, bool plotconst,
 					      bool use_openGL,
 					      QWidget *parent);
   qtgui_sink_c (int fftsize, int wintype,
 		double fc, double bw,
 		const std::string &name,
 		bool plotfreq, bool plotwaterfall,
-		bool plotwaterfall3d, bool plottime,
-		bool plotconst,
+		bool plottime, bool plotconst,
 		bool use_openGL,
 		QWidget *parent);
 
@@ -82,8 +79,7 @@ qtgui_sink_f_sptr qtgui_make_sink_f (int fftsize, int wintype,
 				     double fc=0, double bw=0.0,
 				     const std::string &name="Display",
 				     bool plotfreq=true, bool plotwaterfall=true,
-				     bool plotwaterfall3d=true, bool plottime=true,
-				     bool plotconst=true,
+				     bool plottime=true, bool plotconst=true,
 				     bool use_openGL=true,
 				     QWidget *parent=NULL);
 
@@ -94,16 +90,14 @@ private:
 					      double fc, double bw,
 					      const std::string &name,
 					      bool plotfreq, bool plotwaterfall,
-					      bool plotwaterfall3d, bool plottime,
-					      bool plotconst,
+					      bool plottime, bool plotconst,
 					      bool use_openGL,
 					      QWidget *parent);
   qtgui_sink_f (int fftsize, int wintype,
 		double fc, double bw,
 		const std::string &name,
 		bool plotfreq, bool plotwaterfall,
-		bool plotwaterfall3d, bool plottime,
-		bool plotconst,
+		bool plottime, bool plotconst,
 		bool use_openGL,
 		QWidget *parent);
 
-- 
cgit v1.2.3


From 42caa092c83be06df3c2f38a39285096bf8a4cfe Mon Sep 17 00:00:00 2001
From: Tom Rondeau <trondeau@vt.edu>
Date: Sat, 9 Apr 2011 23:16:02 -0400
Subject: gr-qtgui: removing Guile-specific stuff since there is no way QtGui
 will work with Guile yet. Changed Python QA to complete properly.

---
 config/grc_gr_qtgui.m4           |  4 +---
 gr-qtgui/python/qa_qtgui.py      | 12 +++++++-----
 gr-qtgui/swig/Makefile.am        | 12 ------------
 gr-qtgui/swig/gnuradio/qtgui.scm | 28 ----------------------------
 gr-qtgui/swig/qtgui.test         | 36 ------------------------------------
 gr-qtgui/swig/run_guile_tests.in | 14 --------------
 6 files changed, 8 insertions(+), 98 deletions(-)
 delete mode 100644 gr-qtgui/swig/gnuradio/qtgui.scm
 delete mode 100644 gr-qtgui/swig/qtgui.test
 delete mode 100644 gr-qtgui/swig/run_guile_tests.in

(limited to 'gr-qtgui/python/qa_qtgui.py')

diff --git a/config/grc_gr_qtgui.m4 b/config/grc_gr_qtgui.m4
index a5eac62936..a4592fa413 100644
--- a/config/grc_gr_qtgui.m4
+++ b/config/grc_gr_qtgui.m4
@@ -88,13 +88,11 @@ AC_DEFUN([GRC_GR_QTGUI],[
         gr-qtgui/python/Makefile \
         gr-qtgui/python/run_tests \
         gr-qtgui/swig/Makefile \
-        gr-qtgui/swig/run_guile_tests \
     ])
 
     GRC_BUILD_CONDITIONAL(gr-qtgui,[
         dnl run_tests is created from run_tests.in.  Make it executable.
         AC_CONFIG_COMMANDS([run_tests_qtgui],
-			   [chmod +x gr-qtgui/python/run_tests
-			    chmod +x gr-qtgui/swig/run_guile_tests])
+			   [chmod +x gr-qtgui/python/run_tests])
     ])
 ])
diff --git a/gr-qtgui/swig/Makefile.am b/gr-qtgui/swig/Makefile.am
index ab1acce719..4608687014 100644
--- a/gr-qtgui/swig/Makefile.am
+++ b/gr-qtgui/swig/Makefile.am
@@ -33,14 +33,6 @@ AM_CPPFLAGS = \
 	$(QT_INCLUDES) \
 	$(WITH_INCLUDES)
 
-if GUILE
-nobase_guile_DATA = \
-	gnuradio/qtgui.scm
-endif
-
-noinst_GUILE  = qtgui.test
-
-
 ##############################
 # SWIG interface and library
 TOP_SWIG_IFILES = \
@@ -59,7 +51,3 @@ qtgui_swig_la_swig_libadd = \
 
 # additional SWIG files to be installed
 qtgui_swig_swiginclude_headers = 
-
-if GUILE
-TESTS += run_guile_tests
-endif
\ No newline at end of file
diff --git a/gr-qtgui/swig/gnuradio/qtgui.scm b/gr-qtgui/swig/gnuradio/qtgui.scm
deleted file mode 100644
index fc650d0224..0000000000
--- a/gr-qtgui/swig/gnuradio/qtgui.scm
+++ /dev/null
@@ -1,28 +0,0 @@
-;;;
-;;; Copyright 2011 Free Software Foundation, Inc.
-;;;
-;;; This file is part of GNU Radio
-;;;
-;;; GNU Radio is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 3, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Radio is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
-;;;
-
-;;; Module that just re-exports the qtgui_swig module
-
-(define-module (gnuradio qtgui)
-  #:use-module (gnuradio export-safely)
-  #:use-module (gnuradio qtgui_swig)
-  #:duplicates (merge-generics replace check))
-
-(re-export-all '(gnuradio qtgui_swig))
-
diff --git a/gr-qtgui/swig/qtgui.test b/gr-qtgui/swig/qtgui.test
deleted file mode 100644
index 956a97df91..0000000000
--- a/gr-qtgui/swig/qtgui.test
+++ /dev/null
@@ -1,36 +0,0 @@
-;;; -*- Scheme -*-
-;;;
-;;; Copyright 2011 Free Software Foundation, Inc.
-;;;
-;;; This file is part of GNU Radio
-;;;
-;;; GNU Radio is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 3, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Radio is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
-;;;
-
-;;; If you're using Emacs's Scheme mode:
-;;;   (put 'with-test-prefix 'scheme-indent-function 1)
-
-;;; See the comments in gnuradio/test-suite/lib.scm for info on writing tests.
-;;; See also the very end of the file, where the test-equal, test-eqv
-;;; and test-eq macros are defined.
-
-(define-module (test-module)
-  #:use-module (oop goops)
-  #:use-module (gnuradio core)
-  #:use-module (gnuradio test-suite lib)
-  #:duplicates (merge-generics replace check))
-
-;;; Confirm we can import the module...
-(use-modules (gnuradio qtgui))
-
diff --git a/gr-qtgui/swig/run_guile_tests.in b/gr-qtgui/swig/run_guile_tests.in
deleted file mode 100644
index 5d08b0dd53..0000000000
--- a/gr-qtgui/swig/run_guile_tests.in
+++ /dev/null
@@ -1,14 +0,0 @@
-#!/bin/sh
-
-. @top_builddir@/setup_guile_test_env
-
-# 1st argument is absolute path to hand coded guile source directory
-# 2nd argument is absolute path to component C++ shared library build directory
-# 3nd argument is absolute path to component SWIG build directory
-
-add_local_paths \
-    @srcdir@ \
-    @abs_builddir@ \
-    @abs_builddir@
-
-@GUILE@ -e main -c '(use-modules (gnuradio test-suite guile-test))' -t @srcdir@
diff --git a/gr-qtgui/python/qa_qtgui.py b/gr-qtgui/python/qa_qtgui.py
index dd6529ce0d..9cafd45507 100755
--- a/gr-qtgui/python/qa_qtgui.py
+++ b/gr-qtgui/python/qa_qtgui.py
@@ -22,8 +22,6 @@
 
 from gnuradio import gr, gr_unittest
 import qtgui_swig
-from PyQt4 import QtGui, QtCore
-import sys, sip
 
 class test_qtgui(gr_unittest.TestCase):
 
@@ -34,12 +32,16 @@ class test_qtgui(gr_unittest.TestCase):
         self.tb = None
     
     def test01 (self):
-        #pass
-        # Test to make sure we can instantiate these
-        self.qapp = QtGui.QApplication(sys.argv)
+        # Test to make sure we can instantiate the sink
         self.qtsnk = qtgui_swig.sink_c(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
                                        0, 1, "Test",
                                        True, True, True, True)
+
+    def test02 (self):
+        # Test to make sure we can instantiate the sink
+        self.qtsnk = qtgui_swig.sink_f(1024, gr.firdes.WIN_BLACKMAN_hARRIS, 
+                                       0, 1, "Test",
+                                       True, True, True, True)
         
         
 if __name__ == '__main__':
-- 
cgit v1.2.3